###########
ctrl_mpexec
###########

``ctrl_mpexec`` is a package in the `LSST Science Pipelines <https://pipelines.lsst.io>`_.

It provides a PipelineTask execution framework for single-node processing.
